==> kbib-0.6.1.tar.gz: kbib-0.6.1/kbib/bibfile.h <==
/***************************************************************************
                          bibfile.h  -  description
                             -------------------
    begin                : Sun May 25 2003
    copyright            : (C) 2003 by Thach Nguyen
    email                : thach@dragon.thach.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _BIBFILE_H
#define _BIBFILE_H

#include <iostream>
#include <stdio.h>
#include <ctype.h>
#include <string>
using namespace std;

#include "bibentry.h"


typedef enum{
  BRACE, QUOTE, PAREN, UNKNOWN
}Delimiter;

// avoid recognizing characters >127 (negative when c is signed)
// as control cahrs
int lt_space(char c);
int ispseudoalpha(char c);
char *read_field(FILE *inf, char &c, bool &asStringMacro);
BibEntry* processBibEntryFromString(const char *st, int &last_char, bool ignoreUndefinedType = false, bool ignoredUndefinedField = false);




#endif

==> kbib_0.6.5.orig.tar.gz: kbib-0.6.5/kbib/bibfile.h <==
/***************************************************************************
                          bibfile.h  -  description
                             -------------------
    begin                : Sun May 25 2003
    copyright            : (C) 2003 by Thach Nguyen
    email                : thach.nguyen@rmit.edu.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _BIBFILE_H
#define _BIBFILE_H

#include <iostream>
#include <stdio.h>
#include <ctype.h>
#include <string>
using namespace std;

#include "bibentry.h"


typedef enum{
  BRACE, QUOTE, PAREN, UNKNOWN
}Delimiter;

// avoid recognizing characters >127 (negative when c is signed)
// as control cahrs
int lt_space(char c);
int ispseudoalpha(char c);
char *read_field(FILE *inf, char &c, bool &asStringMacro);
BibEntry* processBibEntryFromString(const char *st, int &last_char, bool ignoreUndefinedType = false, bool ignoredUndefinedField = false);




#endif
